mboehm7 commented on pull request #1558: URL: https://github.com/apache/systemds/pull/1558#issuecomment-1075172743
LGTM - thanks @OlgaOvcharenko this works like a charm, and on a 3x100,000,000 vector the federated quantile is even faster than local (67s vs 87s) because local qsort is still single-threaded (if I force a multi-threaded qsort if comes to 20.5s). -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected]
